Crate gb_cart

Crate gb_cart 

This crate contains routines to read and write Nintendo Game Boy or Game Boy Color ROM internal headers.

This has a companion cli application crate that will read an GB or CGB file and print out its information.

Re-exports

pub use crate::cart::Cart;
pub use crate::error::Error;
pub use crate::metadata::Metadata;
pub use crate::metadata::MetadataRead;

Modules

cart
cart_type
error
licensee
metadata